@@ -18,7 +18,7 @@ def zip_parser(url=None, survey=None):
     # path = "/tmp/pypeds/" + str(int(time.time())) + "/"  # hacky way to make unique path to extract time
     _today = datetime.datetime.today().strftime('%Y%m%d')
     survey_lower = survey.lower()
-    path = "/tmp/" + str(_today) + str(survey) + "/"  # hacky way to make unique path to extract date and survey
+    path = "/tmp/" + str(_today) + str(survey_lower) + "/"  # hacky way to make unique path to extract date and survey
     file = survey + ".zip"
     
     # naive way to do cacheing - if the path for today exists, dont do anything, if it doesnt, get the data
@@ -71,7 +71,7 @@ def read_survey(path):
 def get_hd(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     SURVEY = 'HD' + str(year)
     # build the url
@@ -83,7 +83,7 @@ def get_hd(year):
 def get_ic(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     SURVEY = 'IC' + str(year)
     # build the url
@@ -95,7 +95,7 @@ def get_ic(year):
 def get_adm(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2014 and year <= 2018, "year must be >=2014 and < 2018"
+    assert year >= 2014 and year <= 2018, "year must be >=2014 and <= 2018"
     # build the SURVEY id
     SURVEY = 'ADM' + str(year)
     # build the url
@@ -107,7 +107,7 @@ def get_adm(year):
 def get_sfa(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     sfa_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'SFA' + str(sfa_year)
@@ -120,7 +120,7 @@ def get_sfa(year):
 def get_efc(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     SURVEY = 'EF' + str(year) + "C"
     # build the url
@@ -132,7 +132,7 @@ def get_efc(year):
 def get_icay(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     SURVEY = 'IC' + str(year) + "_AY"
     # build the url
@@ -143,7 +143,7 @@ def get_icay(year):
 def get_om(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2015 and year <= 2018, "year must be >=2015 and < 2018"
+    assert year >= 2015 and year <= 2018, "year must be >=2015 and <= 2018"
     # build the SURVEY id
     SURVEY = 'OM' + str(year) 
     # build the url
@@ -154,7 +154,7 @@ def get_om(year):
 def get_efd(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     SURVEY = 'EF' + str(year)  + "D"
     # build the url
@@ -165,7 +165,7 @@ def get_efd(year):
 def get_ff1(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     ff1_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'F' + str(ff1_year)  + "_F1A"
@@ -177,7 +177,7 @@ def get_ff1(year):
 def get_ff2(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     ff2_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'F' + str(ff2_year)  + "_F2"
@@ -189,7 +189,7 @@ def get_ff2(year):
 def get_ca(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
     # build the SURVEY id
     SURVEY = 'C' + str(year)  + "_A"
     # build the url
